@@ -4,15 +4,7 @@ import pathlib
 
 from .dataset import SeriesData, hash_obj
 from .dataset import SingleData  # noqa:F401 (user convenience)
-from .series_hdf5_generic import SeriesHDF5SinogramMeep
-from .series_hdf5_hyperspy import SeriesHdf5HyperSpy
-from .series_hdf5_qpimage import SeriesHdf5Qpimage, SeriesHdf5QpimageSubjoined
-from .series_zip_tif_holo import SeriesZipTifHolo
-from .series_zip_tif_phasics import SeriesZipTifPhasics
-from .single_hdf5_qpimage import SingleHdf5Qpimage
-from .single_npy_numpy import SingleNpyNumpy
-from .single_tif_holo import SingleTifHolo
-from .single_tif_phasics import SingleTifPhasics
+from . import fmts_ready, fmts_raw_oah
 
 
 class BadFileFormatError(BaseException):
@@ -40,6 +32,7 @@ class WrongFileFormatError(BadFileFormatError):
 class SeriesFolder(SeriesData):
     """Folder-based wrapper file format"""
     # storage_type is implemented as a property
+    priority = -3  # higher than zip file format (issues on Windows)
 
     def __init__(self, *args, **kwargs):
         super(SeriesFolder, self).__init__(*args, **kwargs)
@@ -194,19 +187,11 @@ class SeriesFolder(SeriesData):
 
 
 # the order is important
-formats = [
-    SeriesFolder,
-    SingleHdf5Qpimage,
-    SingleTifPhasics,
-    SingleTifHolo,
-    SingleNpyNumpy,
-    SeriesHDF5SinogramMeep,
-    SeriesHdf5HyperSpy,
-    SeriesHdf5Qpimage,
-    SeriesHdf5QpimageSubjoined,
-    SeriesZipTifPhasics,
-    SeriesZipTifHolo,  # after phasics, b/c phasics has extra keywords
-    ]
+formats = sorted(
+    [SeriesFolder]
+    + fmts_ready.registered_formats
+    + fmts_raw_oah.registered_formats,
+    key=lambda x: x.priority)
 
 # convenience dictionary
 formats_dict = {}
